.. _whats_new:

Release History
===============

A catalog of new features, improvements, and bug-fixes in each release. Follow
links to the relevant GitHub issue or pull request for specific code changes
and any related discussion.

.. include:: whats_new/v0.13.3.txt
.. include:: whats_new/v0.13.2.txt
.. include:: whats_new/v0.13.1.txt
.. include:: whats_new/v0.13.0.txt
.. include:: whats_new/v0.12.2.txt
.. include:: whats_new/v0.12.1.txt
.. include:: whats_new/v0.12.0.txt
.. include:: whats_new/v0.11.3.txt
.. include:: whats_new/v0.11.2.txt
.. include:: whats_new/v0.11.1.txt
.. include:: whats_new/v0.11.0.txt
.. include:: whats_new/v0.10.0.txt
.. include:: whats_new/v0.9.4.txt
.. include:: whats_new/v0.9.3.txt
.. include:: whats_new/v0.9.2.txt
.. include:: whats_new/v0.9.1.txt
.. include:: whats_new/v0.9.0.txt
.. include:: whats_new/v0.8.4.txt
.. include:: whats_new/v0.8.3.txt
.. include:: whats_new/v0.8.2.txt
.. include:: whats_new/v0.8.1.txt
.. include:: whats_new/v0.8.0.txt
.. include:: whats_new/v0.7.0.txt
.. include:: whats_new/v0.6.2.txt
.. include:: whats_new/v0.6.1.txt
.. include:: whats_new/v0.6.0.txt
.. include:: whats_new/v0.5.0.txt
.. include:: whats_new/v0.4.1.txt
.. include:: whats_new/v0.4.0.txt
.. include:: whats_new/v0.3.3.txt
.. include:: whats_new/v0.3.2.txt
.. include:: whats_new/v0.3.1.txt
.. include:: whats_new/v0.3.0.txt
.. include:: whats_new/v0.2.2.txt
.. include:: whats_new/v0.2.1.txt
.. include:: whats_new/v0.2.0.txt
.. include:: whats_new/v0.0.6.txt
